Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorDaniel Calviño Sánchez <danxuliu@gmail.com>2017-05-03 13:45:52 +0300
committerDaniel Calviño Sánchez <danxuliu@gmail.com>2017-05-03 13:45:52 +0300
commite355e953b54f0b610539176b5a3c70812efb66c7 (patch)
tree8bfc3c33e45d2d072672be634d449ef911f06248 /tests
parent97bedb94af6d1981a618a4fa0024edbdf93e1a7b (diff)
Generalize attribute name
Signed-off-by: Daniel Calviño Sánchez <danxuliu@gmail.com>
Diffstat (limited to 'tests')
-rw-r--r--tests/acceptance/features/core/ActorContext.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/tests/acceptance/features/core/ActorContext.php b/tests/acceptance/features/core/ActorContext.php
index 86fe3832f66..c62ebb5e74f 100644
--- a/tests/acceptance/features/core/ActorContext.php
+++ b/tests/acceptance/features/core/ActorContext.php
@@ -39,7 +39,7 @@ use Behat\MinkExtension\Context\RawMinkContext;
* propagates its inherited "base_url" Mink parameter to the Actors as needed.
*
* By default no multiplier for the find timeout is set in the Actors. However,
* it can be customized using the "actorFindTimeoutMultiplier" parameter of the
* ActorContext in "behat.yml".
*
* Every actor used in the scenarios must have a corresponding Mink session
@@ -66,16 +66,16 @@ class ActorContext extends RawMinkContext {
/**
* @var float
*/
- private $actorFindTimeoutMultiplier;
+ private $actorTimeoutMultiplier;
/**
* Creates a new ActorContext.
*
* @param float $actorFindTimeoutMultiplier the find timeout multiplier to
* set in the Actors.
*/
- public function __construct($actorFindTimeoutMultiplier = 1) {
- $this->actorFindTimeoutMultiplier = $actorFindTimeoutMultiplier;
+ public function __construct($actorTimeoutMultiplier = 1) {
+ $this->actorTimeoutMultiplier = $actorTimeoutMultiplier;
}
/**
@@ -110,7 +110,7 @@ class ActorContext extends RawMinkContext {
$this->sharedNotebook = array();
$this->actors["default"] = new Actor($this->getSession(), $this->getMinkParameter("base_url"), $this->sharedNotebook);
- $this->actors["default"]->setFindTimeoutMultiplier($this->actorFindTimeoutMultiplier);
+ $this->actors["default"]->setFindTimeoutMultiplier($this->actorTimeoutMultiplier);
$this->currentActor = $this->actors["default"];
}
@@ -134,7 +134,7 @@ class ActorContext extends RawMinkContext {
public function iActAs($actorName) {
if (!array_key_exists($actorName, $this->actors)) {
$this->actors[$actorName] = new Actor($this->getSession($actorName), $this->getMinkParameter("base_url"), $this->sharedNotebook);
- $this->actors[$actorName]->setFindTimeoutMultiplier($this->actorFindTimeoutMultiplier);
+ $this->actors[$actorName]->setFindTimeoutMultiplier($this->actorTimeoutMultiplier);
}
$this->currentActor = $this->actors[$actorName];
@@ -39,7 +39,7 @@ use Behat\MinkExtension\Context\RawMinkContext;
*
* By default no multiplier for the find timeout is set in the Actors. However,
- * it can be customized using the "actorFindTimeoutMultiplier" parameter of the
+ * it can be customized using the "actorTimeoutMultiplier" parameter of the
* ActorContext in "behat.yml".
*
@@ -66,16 +66,16 @@ class ActorContext extends RawMinkContext {
* Creates a new ActorContext.
*
- * @param float $actorFindTimeoutMultiplier the find timeout multiplier to
- * set in the Actors.
+ * @param float $actorTimeoutMultiplier the timeout multiplier for Actor
+ * related timeouts.
*/